{ pkgs, ... }:
{
  home.packages = [ pkgs.gamescope ];
  programs.niri.settings = {
    window-rules = [
      {
        # handle steam grabbing focus 1000 times on startup
        matches = [
          {
            app-id = "steam";
            title = "Steam";
          }
        ];
        open-focused = false;
      }
      {
        # position steam notifs correctly: https://github.com/YaLTeR/niri/wiki/Application-Issues
        matches = [
          {
            app-id = "steam";
            title = "^notificationtoasts_[\\d]+_desktop$";
          }
        ];
        default-floating-position = {
          x = 0;
          y = 0;
          relative-to = "bottom-right";
        };
        shadow.enable = false;
        border.enable = false;
        baba-is-float = false;
        open-focused = false;
      }
      {
        matches = [
          {
            title = "Guild Wars 2";
            app-id = "steam_app_1284210";
          }
        ];
        border.enable = false;
        shadow.enable = false;
      }
      {
        matches = [
          {
            app-id = "vesktop";
            title = "vesktop";
            is-floating = true;
          }
        ];
        geometry-corner-radius =
          let
            val = 5.;
          in
          {
            bottom-left = val;
            bottom-right = val;
            top-left = val;
            top-right = val;
          };
      }
    ];

    # fix electron apps not doing wayland
    environment.ELECTRON_OZONE_PLATFORM_HINT = "auto";
  };
}
